# 基础模板

- 注意
  - 所有可用组件源码均在代码中，可以根据实际需要去修改
  - 本地已有可以登录的页面，如果本地联调，需要后端本地启动 gateway，提供本地地址给前端进行登录联调
  - 本地开发时，如果后端本地没有启动 gateway 项目，不提供登录接口时，可以通过直接写入 token 来进行本地联调,先登录[测试环境](http://112.5.142.51:14021) ,拿到接口的token
  替换项目中src/core/bootstrap.js文件内的token值,并且[访问这个路径](http://localhost:8003/example/workflow)
  ```js
  store.commit('SET_TOKEN', 'b2815cb3-a885-4a8f-8f04-1d2ec7ded96c')
  ```
  - 路由已经内置动态路由，请在平台建立微应用之后直接建立菜单，然后修改 appid 之后就可以直接展示该 appid 所配置的菜单


基础模板

- 安装依赖

```
yarn install
```

如果很慢，设置为国内源

```
yarn config set registry http://registry.npm.taobao.org/
```

然后再重新 yarn

- 开发模式运行

```
yarn run serve
```

- 编译项目

```
yarn run build
```

- 权限指令

```js
//具体代码看 src/core/directives/action.js
//按钮权限校验
<a-button v-has="'user:add'" >添加用户</a-button>
<a-button v-has="['user:edit']">删除用户</a-button>
//角色校验
<a-button v-hasRole="'test'" >test用户</a-button>
<a-button v-hasRole="['test']">test用户</a-button>
```

- 导入导出Excel组件

见`src/components/ExportExcel/README.md 和src/components/ImportExcel/README.md`

- 全局过滤器

```
请看 src\utils\filter.js
```

- 请求 loading 管理

api 层,例如

```js
export function listExp(query) {
  return axios({
    url: '/activiti/exp/list',
    method: 'get',
    params: query,
    loadingLoader: 'listExp', //增加这个字段
  })
}
```

可使用 `$wait.is('listExp')` 返回值为 true 或 false，常用于 Spin 组件

也可以增加`loadingTips`字段，顶部会自动使用 antd 的 message 的 loading 提示

```js
return axios({
  url: '/activiti/exp/list',
  method: 'get',
  params: query,
  loadingTips: '请求列表中', //增加这个字段
})
```

- 字典调用

```js
this.$store.dispatch('dict/getDict', 'service_hall_type')
```

service_hall_type 为字典 key， 调用此方法后，字典会存在 dict store 里

- 工作流

见`src/components/Activiti/README.md`

- 文件传输组件

上传:见`src/components/SUpload` 可以使用`v-model`或`v-decorator`双向绑定数据
下载:见`src/utils/download.js` 内置封装了一些下载函数,包括通用下载,流下载,blob 下载等,可以直接调用
文件预览:有独立的文件预览系统,通过接口获取预览地址,然后直接打开即可,下面是使用范例

```js
// @/api/common
export function preview(parameter) {
  return axios({
    url: '/file/file/viewUrl',
    method: 'get',
    params: parameter
  })
}
// preview.vue
import { preview } from '@/api/common'
// 这里的id 是文件 id
preview({ id }).then((res) => {
  if (res.code == 0) {
    // 获取到预览地址,直接跳转
    window.open('' + res.msg)
  }
})
```

- 消息通知

后端会对接相关接口,这里主要说明前端如何接入

```js
// @/api/notice
export function saveNotice(parameter) {
  // return axios.post(parameter.id ? api.editNotice: api.addNotice,parameter);
  return axios({
    url: '/api/apicenter/api/notice/push',
    method: 'post',
    data: parameter,
    loadingLoader: 'upDataNotice'
  })
}
// notice.vue
import { saveNotice } from '@/api/notice'
saveNotice({
  userName: 'admin',
  title:'测试标题',
  content:'内容',
  availableTimeStart:'2022-10-10',
  availableTimeEnd:'2023-10-10',
  userIds:'1',
  channelCodes:'MC00001'
}).then((res) => {
  if (res.code == 0) {
    console.log('新增成功')
  }
})
```
- 部署
详见`必读!部署.md`
- 上架
详见`必读!上架.md`

其他未尽事宜参考[线上文档](http://112.5.142.51:32416/Base/front_power.html#%E5%BF%AB%E9%80%9F%E5%BC%80%E5%A7%8B)
如果线上文档和本地冲突，请通知前端负责人提出异议，前端负责人会根据实际情况答复并更新相关文档说明，感谢合作！