import { axios } from '@/utils/request'

const api = {
  user: '/system/user',
  role: '/system/role',
  permission: '/system/menu',
  dept: '/system/dept',
  dictType: '/system/dict/type',
  dictData: '/system/dict/data',
  dist: '/system/districts',
  config: '/system/config',
  oss: '/system/oss'
}

export default api

// user
export function getUserList(parameter) {
  return axios({
    url: api.user + '/list',
    method: 'get',
    params: parameter
  })
}

export function getUser(userId) {
  return axios({
    url: api.user + '/' + `${userId}`,
    method: 'get'
  })
}

export function getUserByNames(userNames) {
  return axios({
    url: api.user + '/' + `getUserByNames`,
    method: 'post',
    data: { userNames }
  })
}

export function saveUser(parameter) {
  return axios({
    url: api.user,
    method: (parameter.userId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delUser(parameter) {
  return axios({
    url: api.user + '/' + parameter,
    method: 'delete'
  })
}

export function changUserStatus(parameter) {
  return axios({
    url: api.user + '/changeStatus',
    method: 'put',
    data: parameter
  })
}

export function resetPwd(parameter) {
  return axios({
    url: api.user + '/resetPwd',
    method: 'put',
    data: parameter
  })
}

// role
export function getRoleList(parameter) {
  return axios({
    url: api.role + '/list',
    method: 'get',
    params: parameter
  })
}

export function getRoleAll() {
  return axios({
    url: api.role + '/all',
    method: 'get'
  })
}

export function saveRole(parameter) {
  return axios({
    url: api.role,
    method: (parameter.roleId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delRole(parameter) {
  return axios({
    url: api.role + '/' + parameter,
    method: 'delete'
  })
}

export function changRoleStatus(parameter) {
  return axios({
    url: api.role + '/changeStatus',
    method: 'put',
    data: parameter
  })
}

export function authDataScope(parameter) {
  return axios({
    url: api.role + '/dataScope',
    method: 'put',
    data: parameter
  })
}

// menu
export function getPermissionAll(parameter) {
  return axios({
    url: api.permission + '/all',
    method: 'get',
    params: parameter
  })
}

export function getPermissions(parameter) {
  return axios({
    url: api.permission + '/list',
    method: 'get',
    params: parameter
  })
}

export function getRolePermAll() {
  return axios({
    url: api.permission + '/treeselect',
    method: 'get'
  })
}

export function getRolePermIds(roleId) {
  return axios({
    url: api.permission + '/roleMenuTreeselect/' + `${roleId}`,
    method: 'get'
  })
}

export function savePerm(parameter) {
  return axios({
    url: api.permission,
    method: (parameter.menuId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delPerm(deptId) {
  return axios({
    url: api.permission + `/${deptId}`,
    method: 'delete'
  })
}

// dept
export function getDeptList(parameter) {
  return axios({
    url: api.dept + '/roleDeptTreeselect/' + parameter,
    method: 'get'
  })
}

// dept
export function getDeptLists(parameter) {
  return axios({
    url: api.dept + '/list',
    method: 'get',
    params: parameter
  })
}

export function getDeptListEnable(parameter) {
  return axios({
    url: '/system/dept/list',
    method: 'get',
    params: parameter
  })
}

export function getRoleDeptIds(roleId) {
  return axios({
    url: '/system/role/' + `${roleId}`,
    method: 'get'
  })
}

export function saveDept(parameter) {
  return axios({
    url: api.dept,
    method: (parameter.deptId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delDept(deptId) {
  return axios({
    url: api.dept + `/${deptId}`,
    method: 'delete'
  })
}

// dictType
export function getDictTypeList(parameter) {
  return axios({
    url: api.dictType + '/list',
    method: 'get',
    params: parameter
  })
}

export function saveDictType(parameter) {
  return axios({
    url: api.dictType,
    method: (parameter.dictId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delDictType(parameter) {
  return axios({
    url: api.dictType + '/' + parameter,
    method: 'delete'
  })
}

// dictData
export function getDictDataList(parameter) {
  return axios({
    url: api.dictData + '/list',
    method: 'get',
    params: parameter
  })
}

export function saveDictData(parameter) {
  return axios({
    url: api.dictData,
    method: (parameter.dictCode > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delDictData(parameter) {
  return axios({
    url: api.dictData + '/' + parameter,
    method: 'delete'
  })
}

// dist 地区
export function getDistList(parameter) {
  return axios({
    url: api.dist + '/list',
    method: 'get',
    params: parameter
  })
}

export function saveDist(parameter) {
  return axios({
    url: api.dist + (parameter.id > 0 ? '/update' : '/save'),
    method: 'post',
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delDist(parameter) {
  return axios({
    url: api.dist + '/remove',
    method: 'post',
    params: parameter
  })
}

// config 配置
export function getConfigList(parameter) {
  return axios({
    url: api.config + '/list',
    method: 'get',
    params: parameter
  })
}

export function saveConfig(parameter) {
  return axios({
    url: api.config,
    method: (parameter.configId > 0 ? 'put' : 'post'),
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delConfig(parameter) {
  return axios({
    url: api.config + '/' + parameter,
    method: 'delete'
  })
}

// oss
export function getOssList(parameter) {
  return axios({
    url: api.oss + '/list',
    method: 'get',
    params: parameter
  })
}

export function saveOss(parameter) {
  return axios({
    url: api.oss + (parameter.id > 0 ? '/update' : '/save'),
    method: 'post',
    data: parameter,
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

export function delOss(parameter) {
  return axios({
    url: api.oss + '/remove',
    method: 'post',
    params: parameter
  })
}

export function getOssConfig() {
  return axios({
    url: api.oss + '/config',
    method: 'get'
  })
}

export function saveOssConfig(parameter) {
  return axios({
    url: api.oss + '/saveConfig',
    method: 'post',
    params: parameter
  })
}
