import router from './router'
import store from './store'
import { log } from './utils/util'
// import storage from 'store'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css' // progress bar style
import { notification } from 'ant-design-vue'
import { setDocumentTitle, domTitle } from '@/utils/domUtil'
import { ACCESS_TOKEN } from '@/store/mutation-types'
import { i18nRender } from '@/locales'
// import { addVisitedNum } from '@/api/serviceHall'
import cookieUtil from 'js-cookie'

NProgress.configure({ showSpinner: false }) // NProgress Configuration
if (window.__POWERED_BY_QIANKUN__) {
  // eslint-disable-next-line no-undef
  __webpack_public_path__ = window.__INJECTED_PUBLIC_PATH_BY_QIANKUN__
}

const allowList = ['login'] // no redirect allowList
const loginRoutePath = '/user/login'
const defaultRoutePath = '/'

const addRouterAndNext = (to, from, next) => {
  // 在这边打开动态路由
  router.addRoutes(store.getters.addRouters)
  store.commit('SET_ISCOMPLETE', true)
  const redirect = decodeURIComponent(from.query.redirect || to.path)
  if (to.path === redirect) {
    // console.log('to.path === redirect', to)
    // hack方法 确保addRoutes已完成 ,set the replace: true so the navigation will not leave a history record
    next({ ...to, replace: true })
  } else {
    // console.log('to.path != redirect', redirect)
    // 跳转到目的路由
    next({ path: redirect })
  }
}

router.beforeEach((to, from, next) => {
  console.log(to)
  console.log(from)
  // if (to.name && to.matched.length === 0) {
  //   console.log(to)
  //   next({ path: '/403' })
  // NProgress.start() // start progress bar
  to.meta && (typeof to.meta.title !== 'undefined' && setDocumentTitle(`${i18nRender(to.meta.title)} - ${domTitle}`))
  const queryToken = to.query.token // pc微信应用内打开
  if (queryToken) {
    cookieUtil.set(ACCESS_TOKEN, queryToken)
  }
  if (allowList.includes(to.name)) {
    // 在免登录白名单，直接进入
    next()
  } else {
    /* has token */
    if (cookieUtil.get(ACCESS_TOKEN)) {
      if (to.path === loginRoutePath) {
        next({ path: defaultRoutePath })
        NProgress.done()
      } else {
        if (store.getters.roles.length === 0) {
          log('获取应用信息', '', store.getters?.appInfo)
          const applicationId = store.getters?.appInfo?.applicationId + ''
          Promise.all([store.dispatch('GetInfo'), store.dispatch('GenerateRoutes')])
            .then(() => {
              log('装载路由', null, store.getters.addRouters)
              // 把已获取到的路由菜单加入到路由表中
              const oldAppId = cookieUtil.get('applicationId') + ''
              console.log(oldAppId, applicationId)
              if (oldAppId === applicationId) {
                addRouterAndNext(to, from, next)
              }
            }).catch(() => {
              notification.error({
                message: '错误',
                description: '请求用户信息失败，请重试'
              })
              store.dispatch('Logout').then(() => {
                next({ path: loginRoutePath, query: { redirect: to.fullPath } })
              })
            })
        } else if (!store.state.permission.isComplete) {
          // debugger
          addRouterAndNext(to, from, next)
        } else {
          log('已有用户信息，直接跳转==》', null, to)
          next()
        }
      }
    } else {
      next({ path: loginRoutePath })
      NProgress.done() // if current page is login will not trigger afterEach hook, so manually handle it
    }
  }
})

router.afterEach(() => {
  NProgress.done() // finish progress bar
})
