import Vue from 'vue'
import { getDictArray, getBjOrZyDict } from '@/utils/dict'
import { getlistXlgl } from '@/api/common'

const state = {}
const mutations = {
  SET_DIC_STATE: (state, payload) => {
    Vue.set(state, payload.key, payload.value)
  }
}

const actions = {
  // 字典
  getDict({ commit, state }, payload) {
    if (!state[payload]?.length && !state[payload]?.[0]?.loading) {
      commit('SET_DIC_STATE', { key: payload, value: [{ loading: true, dictValue: 'loading', dictCode: 'loading', dictLabel: 'loading' }] }) // 防止字典数据同时加载，，应该没问题
      return new Promise((resolve, reject) => {
        getDictArray(payload)
          .then(res => {
            const dict = res.data?.map(item => ({
              dictValue: item.dictValue,
              dictCode: item.dictCode,
              dictLabel: item.dictLabel,
              value: item.dictValue,
              label: item.dictLabel
            })) || []
            commit('SET_DIC_STATE', { key: payload, value: dict })
            resolve(dict)
          })
          .catch(error => {
            commit('SET_DIC_STATE', { key: payload, value: [] })
            reject(error)
          })
      })
    } else {
      console.log(payload + '字典已缓存')
      return state[payload]
    }
  },
  getXq({ commit, state }, payload) {
    console.log('****')
    if (!state[payload]?.length && !state[payload]?.[0]?.loading) {
      commit('SET_DIC_STATE', { key: payload, value: [{ loading: true, dictValue: 'loading', dictCode: 'loading', dictLabel: 'loading' }] }) // 防止字典数据同时加载，，应该没问题
      return new Promise((resolve, reject) => {
        getlistXlgl(payload)
          .then(res => {
            const dict = res.data || []
            console.log('学期返回值', dict)
            commit('SET_DIC_STATE', { key: payload, value: dict })
            resolve(dict)
          })
          .catch(error => {
            commit('SET_DIC_STATE', { key: payload, value: [] })
            reject(error)
          })
      })
    } else {
      console.log(payload + '字典已缓存')
      return state[payload]
    }
  },
  // 获取学工班级或专业字典
  getBjOrZyDict({ commit, state }, payload) {
    return new Promise((resolve, reject) => {
      getBjOrZyDict(payload.apiType, payload.parameter)
        .then(res => {
          let dict=[]
          if (payload.apiType === 'listBjmcByFdy') {
            dict =res.data
            
          } else {
            dict = res.data.map(item => ({
              dictLabel: payload.apiType === 'listBj' ? item.bjmc : item.zymc
            }))
          }
          
          resolve(dict)
        })
        .catch(error => {
          reject(error)
        })
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
