import { login, getInfo, logout } from '@/api/login'
import { ACCESS_TOKEN } from '@/store/mutation-types'
import { welcome } from '@/utils/util'
import cookieUtil from 'js-cookie'

const user = {
  state: {
    userId: '',
    userName: '',
    token: '',
    name: '',
    welcome: '',
    avatar: '',
    xgh: '',
    roles: [],
    buttons: [], // 按钮权限
    info: {},
    personalInfo: {},
    createApply: {},
    syxsCreateApply: {},
    qgzxXsInfo: {},
    isSuperAdmin: false
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      cookieUtil.set(ACCESS_TOKEN, token, 12 * 60 * 60 * 1000)
      state.token = token
    },
    SET_NAME: (state, { name, welcome }) => {
      state.name = name
      state.welcome = welcome
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
      state.isSuperAdmin = roles.includes('super_admin')
    },
    SET_INFO: (state, info) => {
      state.info = info
    },
    SET_BUTTONS: (state, buttons) => {
      state.buttons = buttons
    },
    SET_XGH: (state, xgh) => {
      state.xgh = xgh
    },
    SET_USERNAME: (state, userName) => {
      state.userName = userName
    },
    SET_USERID: (state, userId) => {
      state.userId = userId
    },
    SET_PERSONAL: (state, info) => {
      state.personalInfo = info
    },
    SET_CREATEAPPLY: (state, info) => {
      state.createApply = info
    },
    SET_SYXSCREATEAPPLY: (state, info) => {
      state.syxsCreateApply = info
    },
    SET_QGZXXSINFO: (state, info) => {
      state.qgzxXsInfo = info
    }
  },

  actions: {
    // 登录
    Login ({ commit }, userInfo) {
      return new Promise((resolve, reject) => {
        login(userInfo).then(response => {
          const result = response
          cookieUtil.set(ACCESS_TOKEN, result.data.access_token, 12 * 60 * 60 * 1000)
          commit('SET_TOKEN', result.data.access_token)
          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo ({ commit }) {
      return new Promise((resolve, reject) => {
        getInfo().then(response => {
          const result = response
          if (result.roles) {
            commit('SET_ROLES', result.roles)
            commit('SET_BUTTONS', result.permissions)
            commit('SET_USERID', result.user.userId)
            commit('SET_XGH', result.user.userName)
            console.log(result.user.userName)
            commit('SET_USERNAME', result.user.userName)
            commit('SET_INFO', result)
          } else {
            reject(new Error('getInfo: roles must be a non-null array !'))
          }
          commit('SET_NAME', { name: result.user.nickName, welcome: welcome() })
          commit('SET_AVATAR', result.user.avatar || '/avatar2.jpg')
          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 登出
    Logout ({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then((res) => {
          resolve()
        }).catch((error) => {
          reject(error)
        }).finally(() => {
          console.log(12312312)
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_INFO', {})
          commit('SET_PERSONAL', {})
          commit('SET_CREATEAPPLY', {})
          commit('SET_SYXSCREATEAPPLY', {})
          commit('SET_USERNAME', '')
          commit('SET_QGZXXSINFO', {})
          cookieUtil.remove(ACCESS_TOKEN)
        })
      })
    }

  }
}

export default user
