import { axios } from '@/utils/request'
import { saveDictData, saveDictType } from '@/api/system'
const api = {
  dictData: '/system/dict/data'
}

// 字典两种用法，各有优缺点
// 1.Map 需要数组的时候构造数组不方便
// operTypeMap = await getDictMap('sys_oper_type')
// this.operTypeMap = operTypeMap
// this.operTypeMap.forEach((value, key, mymap) => {
//   this.businessTypes.push({ code: key, label: value })
// })
// 2.数组 在modal调用没有map方便
// this.businessTypes = await getDictArray('sys_oper_type')
// this.businessTypes.map(d => {
//   operTypeMap[d.dictValue] = { text: d.dictLabel }
// })
// this.operTypeMap = operTypeMap

/**
 * 根据类型获取字典内容 返回Map
 * @param {String} dictType 字典类型
 */
export function getDictMap (dictType) {
  return new Promise((resolve, reject) => {
  // ajax
    axios({
      url: api.dictData + `/type/` + dictType,
      method: 'get'
    }).then(res => {
      const map = new Map()
      res.data.map(d => {
        map.set(d.dictValue, d.dictLabel)
      })
      resolve(map)
    }).catch(err => {
      reject(err)
    })
  })
}
/**
 * 根据类型获取字典内容 返回数组
 * @param {String} dictType 字典类型
 */
export function getDictArray (dictType) {
  return axios({
    url: api.dictData + '/type/' + dictType,
    method: 'get',
    loadingLoader:dictType,
  })
}

/**
 * 获取学工班级或者专业字典
 * @param {String} apiType 接口拼接名
 */
export function getBjOrZyDict (apiType,parameter={}) {
  return axios({
    url: '/xg/xgdict/' + apiType,
    method: 'post',
    data:parameter,
    loadingLoader:apiType,
  })
}
/**
 * 快速添加字典,用于开发
 * 建议使用完检查一下
 * @private
 * 'dictCode', 'dictType', 'dictLabel', 'dictValue', 'dictSort', 'status', 'remark'
 */
function _addDictQuick(name, code, arr = [], remark = '') {
  const save = () => {
    arr.forEach((e, index) => {
      let value = index + 1
      let label = e
      if (typeof e === 'object') {
        value = e.value
        label = e.label
      }
      const data = {
        'dictCode': 0,
        'dictType': code,
        'dictLabel': label,
        'dictValue': value,
        'dictSort': index + 1,
        'status': '0'
      }
      saveDictData({
        'dictCode': 0,
        'dictType': code,
        'dictLabel': label,
        'dictValue': value,
        'dictSort': index + 1,
        'status': '0'
      }).then(e => {
        console.log('创建字典项成功', data)
      })
    })
  }

  if (name) {
    saveDictType({
      dictId: 0,
      dictName: name,
      dictType: code,
      remark: remark || (name + '字典'),
      status: '0'
    }).then(res => {
      if (res.code === 0) {
        this.$message.success('建立字典成功')
        save()
      } else {
        this.$message.error(res.msg)
        console.log('======》更新原有字典')
        save()
      }
    }).catch(e => {
      console.log('======》更新原有字典')
      save()
    })
  }
}

// window._addDictQuick = _addDictQuick
