import { pureAxios, axios } from '@/utils/request'

const downloadUrl = '/system/common/download'

const mimeMap = {
  xlsx: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
  zip: 'application/zip',
  xml: 'application/xml',
  octetStream: 'application/octet-stream'
}

export function exportExcel (url, params) {
  axios({
    url: url,
    method: 'post',
    params: params
  }).then(res => {
    if (res.code === 0) {
      downloadXlsx(res.msg)
    }
  })
}

/**
 * 下载.xlsx文件
 * @param {String} filename 文件名
 */
export function downloadXlsx (filename) {
  pureAxios({
    url: downloadUrl,
    method: 'get',
    params: { fileName: filename, delete: true },
    responseType: 'blob'
  }).then(res => {
    resolveBlob(res, mimeMap.xlsx)
  })
}

/**
 * 下载流
 * @param url
 */
export function downloadStream(url, params = {}) {
  return axios({
    url: url,
    method: 'get',
    params: params,
    responseType: 'blob'
  }).then(res => {
    resolveBlob(res, mimeMap.octetStream)
  })
}

/**
 * 代码生成并下载为zip
 * @param {String} url 链接
 * @param {String} tables 表名
 */
export function genCodeZip (url, tables) {
  axios({
    url: url,
    method: 'get',
    params: { tables: tables },
    responseType: 'blob'
  }).then(res => {
    resolveBlob(res, mimeMap.zip)
  })
}

/**
 * 解析blob响应内容并下载
 * @param {*} res blob响应内容
 * @param {String} mimeType MIME类型
 * @param {String} filename 文件名,如果不传则使用后端命名的文件名，
 */
export function resolveBlob (res, mimeType, filename = '') {
  const aLink = document.createElement('a')
  var blob = new Blob([res.data], { type: mimeType })
  var fileName = filename

  if (!filename) {
    // //从response的headers中获取filename, 后端response.setHeader("Content-disposition", "attachment; filename=xxxx.docx") 设置的文件名;
    var patt = new RegExp('filename=([^;]+\\.[^\\.;]+);*')
    var contentDisposition = decodeURI(res.headers['content-disposition'])
    var result = patt.exec(contentDisposition)
    fileName = result?.[1]
  }

  aLink.href = URL.createObjectURL(blob)
  aLink.setAttribute('download', fileName) // 设置下载文件名称
  document.body.appendChild(aLink)
  aLink.click()
  document.body.removeChild(aLink)
  window.URL.revokeObjectURL(aLink.href)
}

// blob转文件流下载
export function BlobToFile(data, filename) {
  const content = data
  const blob = new Blob([content])
  if ('download' in document.createElement('a')) {
    const elink = document.createElement('a')
    elink.download = filename || data.fileName
    elink.style.display = 'none'
    elink.href = URL.createObjectURL(blob)
    document.body.appendChild(elink)
    elink.click()
    URL.revokeObjectURL(elink.href)
    document.body.removeChild(elink)
  } else {
    navigator.msSaveBlob(blob, filename || data.fileName)
  }
}
// 通用下载方法
export function download(url, params, filename, loadingLoader, loadingTips) {
  return axios
    .post(url, params, {
      responseType: 'blob',
      loadingLoader: loadingLoader,
      loadingTips: loadingTips || '文件下载中...'
    })
    .then(data => {
      resolveBlob(data, undefined, filename)
      // BlobToFile(data, filename);
      return data.data
    })
    .catch(r => {
      return Promise.reject(r) // console.error(r);
    })
}
