import { modalAction } from '@/utils/constant'
import pick from 'lodash.pick'
import { STable } from '@/components'
import sMock from '@/utils/simpleMock'

const onValuesChangeMixin = {
  methods: {
    // 设置选择代码
    onValuesChange(value, vNode) {
      console.log('设置代码', value, vNode)
      // 多选
      if (value instanceof Array) {
        let _name
        const _value = []
        vNode.forEach((item, index) => {
          _name = item?.data?.attrs?.['data-setName']
          _value.push(item?.data?.attrs?.['data-value'])
        })
        this.setFields(_name, _value.length ? _value.join(',') : undefined)
      } else {
        this.setFields(vNode?.data?.attrs?.['data-setName'], vNode?.data?.attrs?.['data-value'])
      }
    },
    setFields(key, value) {
      if (value instanceof Array && key instanceof Array) {
        key.forEach((k, index) => {
          console.log(k, value[index])
          this.form.setFieldsValue({ [k]: value[index] })
        })
      } else {
        console.log(key, value)
        this.form.setFieldsValue({ [key]: value })
      }
    }
  }
}

/**
 * 弹窗公共逻辑封装
 */
const modalMixin = {
  mixins: [onValuesChangeMixin],
  data() {
    return {
      modelType: 'add',
      modelTitle: '新增',
      visible: false,
      disabled: false,
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      mdl: {},
      form: null, // form自己指定
      pickKeyArr: []
    }
  },
  methods: {
    add(record = {}) {
      // 只有工作流有authority, 但保存多传这个字段好像也没事，
      this.edit({ id: 0, authority: { canEdit: true }, ...record }, modalAction.add)
    },
    async edit(record, type) {
      this.resetFields()
      this.modelType = type
      const otherData = this.beforeVisible ? await this.beforeVisible(record, type) : {}
      if (otherData) {
        this.visible = true
        this.$nextTick(() => {
          // 特殊字段处理
          this.mdl = this.beforeSetData
            ? Object.assign({}, record, otherData, this.beforeSetData(Object.assign({}, record), type, otherData))
            : Object.assign({}, record, otherData)
          if (this.pickKeyArr?.length) {
            // eslint-disable-next-line no-unused-expressions
            this.form?.setFieldsValue?.(pick.apply(this, [this.mdl, ...this.pickKeyArr]))
          } else {
            // eslint-disable-next-line no-unused-expressions
            this.form?.setFieldsValue?.(this.mdl)
          }
          this.afterSetData && this.afterSetData(type)
        })
      }
    },
    resetFields() {
      this.form && this.form.resetFields()
    },
    handleCancel() {
      this.visible = false
      this.mdl = {}
      this.resetFields()
      this.modelType = modalAction.add
    }
  },
  watch: {
    modelType: {
      immediate: true,
      handler(val) {
        console.log('modelType变更', val)
        switch (val) {
          case modalAction.add:
            this.disabled = false
            this.modelTitle = '新增'
            break
          case modalAction.edit:
            this.disabled = false
            this.modelTitle = '编辑'
            break
          case modalAction.view:
            this.disabled = true
            this.modelTitle = '查看'
            break
          case modalAction.approval:
            this.disabled = this.mdl.createBy
            this.modelTitle = '办理'
            break
        }
      }
    }
  }
}

const sTableMixin = {
  data() {
    return {
      selectedRowKeys: [],
      selectedRows: [],
      columns: [],
      pageInfo: {},
      loadData: (parameter) => {
        return sMock.tableRow()
      }
    }
  },
  components: {
    STable
  },
  methods: {
    onSelectChange(selectedRowKeys, selectedRows) {
      console.log('onSelectChange', { selectedRowKeys, selectedRows })
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    clearSelectRows() {
      this.selectedRowKeys = []
      this.selectedRows = []
    }
  }
}
/**
 * 时间 range 公共逻辑 (开始时间控制结束时间）
 * 用于 <a-time-picker/> 组件
 */
const timeRangeMixin = {
  data() {
    return {
      // 默认禁止的时间--为数字数组
      disabledHours: [],
      disabledMinutes: [],
      disabledSeconds: [],
      startTime: '00:00:00',
      endTime: '23:59:59'
    }
  },
  methods: {
    changeTime(val, dateStrings, type) {
      if (type === 'startTime') {
        this.startTime = dateStrings
      } else {
        this.endTime = dateStrings
      }
    },
    getDisabledHours () {
      const hours = []
      const time = this.startTime
      const timeArr = time.split(':')
      for (let i = 0; i < parseInt(timeArr[0]); i++) {
        hours.push(i)
      }
      return hours
    },
    getDisabledMinutes (selectedHour) {
      const time = this.startTime
      const timeArr = time.split(':')
      const minutes = []
      if (selectedHour === parseInt(timeArr[0])) {
        for (let i = 0; i < parseInt(timeArr[1]); i++) {
          minutes.push(i)
        }
      }
      return minutes
    },
    getDisabledSeconds(selectedHour, selectedMinute) {
      const time = this.startTime
      const timeArr = time.split(':')
      const second = []
      if (selectedHour === parseInt(timeArr[0]) && selectedMinute === parseInt(timeArr[1])) {
        for (let i = 0; i <= parseInt(timeArr[2]); i++) {
          second.push(i)
        }
      }
      return second
    }

  }
}

export {
  modalMixin,
  onValuesChangeMixin,
  sTableMixin,
  timeRangeMixin
}
