import store from '@/store'

export function actionToObject(json) {
  try {
    return JSON.parse(json)
  } catch (e) {
    console.log('err', e.message)
  }
  return []
}

// 权限检查方法
export function checkPermission(value) {
  // userId=1直接拥有所以权限
  const userId = store.getters.userId
  if (userId === 1 || store.state.user.isSuperAdmin) return true
  // 获取用户按钮权限
  let isExist = false
  const dynamicButtons = store.getters.buttons
  if (dynamicButtons === undefined || dynamicButtons === null || dynamicButtons.length < 1) {
    return isExist
  }
  isExist = dynamicButtons.some(permission => {
    return (typeof value === 'string' ? [value] : value).includes(permission)
  })
  // console.log("store.getters",value,isExist)
  return isExist
}

// 判断同时具有多个权限
export function checkMorePermission(value) {
  // userId=1直接拥有所以权限
  const userId = store.getters.userId
  if (userId === 1 || store.state.user.isSuperAdmin) return true
  // 获取用户按钮权限
  const isExist = false
  const dynamicButtons = store.getters.buttons
  // console.log("dynamicButtons",dynamicButtons);
  if (dynamicButtons === undefined || dynamicButtons === null || dynamicButtons.length < 1) {
    return isExist
  }
  let count = 0
  dynamicButtons.map(permission => {
    ((typeof value === 'string' ? [value] : value).includes(permission)) && count++
  })
  return value.length == count
}

/**
 * 角色权限校验
 * @param {Array} value 校验值
 * @returns {Boolean}
 */
export function checkRole(value = []) {
  const userId = store.getters.userId
  if (userId === 1 || store.state.user.isSuperAdmin) return true
  // 获取用户按钮权限
  let isExist = false
  const dynamicRoles = store.getters.roles
  console.log(dynamicRoles)
  if (dynamicRoles === undefined || dynamicRoles === null || dynamicRoles.length < 1) {
    return isExist
  }
  isExist = dynamicRoles.some(roles => {
    return value.includes(roles)
  })
  return isExist
}

/**
 * 判断用户的角色的权限字符
 * @param {Array} userRole 校验值
 * @param force {Boolean} 是否只验证userRole中的角色（admin不返回true）
 * @returns {Boolean} role
 *
 **/
export function getUserRole(userRole, force = false) {
  const dynamicRoles = store.getters.roles
  let isRole = false
  if (dynamicRoles === undefined || dynamicRoles === null || dynamicRoles.length < 1) {
    return isRole
  }
  if (!(userRole.includes('xg_xs') || force)) {
    const userId = store.getters.userId
    if (userId === 1) return true
  }
  isRole = dynamicRoles.some(roles => {
    return userRole.includes(roles)
  })
  return isRole
}
