import axios from 'axios'
import store from '@/store'
// import storage from 'store'
// import { VueAxios } from './axios'
import { notification, message } from 'ant-design-vue'
import { ACCESS_TOKEN } from '@/store/mutation-types'
import qs from 'qs'
import cookieUtil from 'js-cookie'

const errorCode = {
  '401': '认证失败，无法访问系统资源',
  '403': '当前操作没有权限',
  '404': '访问资源不存在',
  'default': '系统未知错误,请反馈给管理员'
}
const baseURL = process.env.VUE_APP_API_BASE_URL
axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'
// axios.defaults.withCredentials = true
// 创建 axios 实例
const request = axios.create({
  baseURL: baseURL, // api base_url
  timeout: 30 * 1000 // 请求超时时间
})
export const pureAxios = axios.create({
  baseURL: baseURL, // api base_url
  timeout: 30 * 1000 // 请求超时时间
})
const fileUpload = axios.create({
  baseURL: baseURL, // api base_url
  timeout: 300 * 1000 // 请求超时时间
})

const requestInterceptors = (config) => {
  /** 如果有loading Loader,开启wait插件 */
  if (config) {
    if (config.loadingLoader) {
      window.$wait.start(config.loadingLoader)
    }
    if (config.loadingTips) {
      config.loadingTips = message.loading(config.loadingTips)
    }
  }
}

const responseInterceptors = (config) => {
  /** 清除该请求的loading载体 */
  if (config) {
    if (config.loadingLoader) {
      window.$wait.end(config.loadingLoader)
    }
    if (config.loadingTips && typeof config.loadingTips === 'function') {
      config.loadingTips()
    }
  }
}
const err = (error) => {
  // console.log(error)
  responseInterceptors(error.config)
  if (error.response) {
    const data = error.response.data
    if (error.response.status === 403) {
      notification.error({
        message: 'Forbidden',
        description: data.message
      })
    }
    if (error.response.status === 401 && !(data.result && data.result.isLogin)) {
      notification.error({
        message: '登录过期',
        description: '登录状态已过期,请重新登录',
        key: '401'
      })
      store.dispatch('Logout').then(() => {
        setTimeout(() => {
          window.location.reload()
        }, 1500)
      })
    } else if (error.response.status === 500 || error.response.data?.msg) {
      notification.error({
        message: error.response.data?.msg ? '错误' : '系统无响应',
        description: error.response.data?.msg || '后端接口无响应,请稍后再试'
      })
    }
  } else if (error.message.includes('timeout')) {
    notification.error({
      message: '系统繁忙',
      description: '系统接口请求超时,请稍后再试'
    })
  } else {
    notification.error({
      message: error.message,
      description: error.message
    })
  }
  return Promise.reject(error)
}

// request interceptor
const reqInterceptor = config => {
  const token = cookieUtil.get(ACCESS_TOKEN)
  if (token) {
    config.headers['Authorization'] = 'Bearer ' + token // 让每个请求携带自定义 token 请根据实际情况自行修改
  }
  const appInfo = store.getters.appInfo
  if (appInfo) {
    config.headers['applicationId'] = appInfo.applicationId // 应用ID
  }
  if (config.method === 'get') {
    // get的时候传输数组
    config.paramsSerializer = function (params) {
      return qs.stringify(params, { arrayFormat: 'repeat' })
    }
  }
  requestInterceptors(config)
  return config
}

request.interceptors.request.use(reqInterceptor, err)

// pureAxios.interceptors.request.use(config => {
//   const token = storage.get(ACCESS_TOKEN)
//   if (token) {
//     config.headers['token'] = token // 让每个请求携带自定义 token 请根据实际情况自行修改
//   }
//   return config
// }, err)

// response interceptor
const respInterceptor = (response) => {
  responseInterceptors(response.config)
  const code = response.data.code
  const msg = errorCode[code] || response.data.msg || response.data.repMsg || errorCode['default']
  // console.log(response)
  // Blob下载失败异常处理
  if (response.data instanceof Blob) {
    if (response.data.type !== 'application/json') {
      return response
    } else {
      new Response(response.data).json().then(resData => {
        notification.error({
          message: '错误',
          description: resData.msg
        })
      })
      // return response
      // console.log("response",response,response.code)
    }
  } else if (code === 0 || response.data.success) {
    return response.data
  } else if (code > 0 && code < 100) {
    return response.data
  } else if (code >= 100 && code < 300) {
    message.error(msg)
    return Promise.reject(response?.data || new Error('error'))
  } else {
    if (msg.indexOf('<br/>') > -1) {
      notification.error({
        message: '错误',
        description: (h) => {
          const child = msg.split('<br/>').map(item => {
            return h('div', null, item)
          })
          return h('div', { class: 'notifyContent' }, child)
        } // console.log(h)//'<span>111</span>'
      })
    } else {
      notification.error({
        message: '错误',
        description: msg
      })
    }

    // eslint-disable-next-line prefer-promise-reject-errors
    return Promise.reject(response?.data || 'error')
  }
}

request.interceptors.response.use(respInterceptor, err)

fileUpload.interceptors.request.use(reqInterceptor, err)
fileUpload.interceptors.response.use(respInterceptor, err)

// const installer = {
//   vm: {},
//   install (Vue) {
//     Vue.use(VueAxios, request)
//   }
// }
// function req(params) {
//   let cancelLoading = null
//   if (params.loadingTips) {
//     cancelLoading = message.loading(params.loadingTips)
//   }
//   return request(params)
//     .finally(() => {
//       if (cancelLoading) cancelLoading()
//       responseInterceptors(params)
//     })
// }

export default request

export {
  // installer as VueAxios,
  request as axios,
  fileUpload as upload
}
